@@ -59,7 +59,7 @@ ORGMODE = 14
 DOUBLE_BORDER = 15
 RANDOM = 20
 
-_re = re.compile(r"\033\[[0-9;]*m")
+_re = re.compile(r"\033\[[0-9;]*m|\033\(B")
 
 
 def _get_size(text):
@@ -92,6 +92,7 @@ class PrettyTable:
             Allowed values: FRAME, ALL, NONE
         int_format - controls formatting of integer data
         float_format - controls formatting of floating point data
+        custom_format - controls formatting of any column using callable
         min_table_width - minimum desired table width, in characters
         max_table_width - maximum desired table width, in characters
         min_width - minimum desired field width, in characters
@@ -134,6 +135,8 @@ class PrettyTable:
         self.min_width = {}
         self.int_format = {}
         self.float_format = {}
+        self.custom_format = {}
+
         if field_names:
             self.field_names = field_names
         else:
@@ -156,6 +159,7 @@ class PrettyTable:
             "vrules",
             "int_format",
             "float_format",
+            "custom_format",
             "min_table_width",
             "max_table_width",
             "padding_width",
@@ -219,6 +223,7 @@ class PrettyTable:
         self.min_width = kwargs["min_width"] or {}
         self.int_format = kwargs["int_format"] or {}
         self.float_format = kwargs["float_format"] or {}
+        self.custom_format = kwargs["custom_format"] or {}
 
         self._min_table_width = kwargs["min_table_width"] or None
         self._max_table_width = kwargs["max_table_width"] or None
@@ -307,6 +312,16 @@ class PrettyTable:
     def __str__(self):
         return self.get_string()
 
+    def __repr__(self):
+        return self.get_string()
+
+    def _repr_html_(self):
+        """
+        Returns get_html_string value by default
+        as the repr call in Jupyter notebook environment
+        """
+        return self.get_html_string()
+
     ##############################
     # ATTRIBUTE VALIDATORS       #
     ##############################
@@ -361,6 +376,9 @@ class PrettyTable:
             self._validate_int_format(option, val)
         elif option == "float_format":
             self._validate_float_format(option, val)
+        elif option == "custom_format":
+            for k, formatter in val.items():
+                self._validate_function(f"{option}.{k}", formatter)
         elif option in (
             "vertical_char",
             "horizontal_char",
@@ -847,6 +865,31 @@ class PrettyTable:
             for field in self._field_names:
                 self._float_format[field] = val
 
+    @property
+    def custom_format(self):
+        """Controls formatting of any column using callable
+        Arguments:
+
+        custom_format - Dictionary of field_name and callable"""
+        return self._custom_format
+
+    @custom_format.setter
+    def custom_format(self, val):
+        if val is None:
+            self._custom_format = {}
+        elif isinstance(val, dict):
+            for k, v in val.items():
+                self._validate_function(f"custom_value.{k}", v)
+            self._custom_format = val
+        elif hasattr(val, "__call__"):
+            self._validate_function("custom_value", val)
+            for field in self._field_names:
+                self._custom_format[field] = val
+        else:
+            raise Exception(
+                "The custom_format property need to be a dictionary or callable"
+            )
+
     @property
     def padding_width(self):
         """The number of empty spaces between a column's edge and its content
@@ -1370,10 +1413,12 @@ class PrettyTable:
 
     def _format_value(self, field, value):
         if isinstance(value, int) and field in self._int_format:
-            value = ("%%%sd" % self._int_format[field]) % value
+            return ("%%%sd" % self._int_format[field]) % value
         elif isinstance(value, float) and field in self._float_format:
-            value = ("%%%sf" % self._float_format[field]) % value
-        return str(value)
+            return ("%%%sf" % self._float_format[field]) % value
+
+        formatter = self._custom_format.get(field, (lambda f, v: str(v)))
+        return formatter(field, value)
 
     def _compute_table_width(self, options):
         table_width = 2 if options["vrules"] in (FRAME, ALL) else 0
@@ -1474,14 +1519,14 @@ class PrettyTable:
 
         return rows
 
-    def _format_row(self, row, options):
+    def _format_row(self, row):
         return [
             self._format_value(field, value)
             for (field, value) in zip(self._field_names, row)
         ]
 
-    def _format_rows(self, rows, options):
-        return [self._format_row(row, options) for row in rows]
+    def _format_rows(self, rows):
+        return [self._format_row(row) for row in rows]
 
     ##############################
     # PLAIN TEXT STRING METHODS  #
@@ -1505,6 +1550,7 @@ class PrettyTable:
             Allowed values: FRAME, ALL, NONE
         int_format - controls formatting of integer data
         float_format - controls formatting of floating point data
+        custom_format - controls formatting of any column using callable
         padding_width - number of spaces on either side of column data (only used if
             left and right paddings are None)
         left_padding_width - number of spaces on left hand side of column data
@@ -1545,7 +1591,7 @@ class PrettyTable:
         rows = self._get_rows(options)
 
         # Turn all data in all rows into Unicode, formatted as desired
-        formatted_rows = self._format_rows(rows, options)
+        formatted_rows = self._format_rows(rows)
 
         # Compute column widths
         self._compute_widths(formatted_rows, options)
@@ -1868,6 +1914,7 @@ class PrettyTable:
             Allowed values: FRAME, ALL, NONE
         int_format - controls formatting of integer data
         float_format - controls formatting of floating point data
+        custom_format - controls formatting of any column using callable
         padding_width - number of spaces on either side of column data (only used if
             left and right paddings are None)
         left_padding_width - number of spaces on left hand side of column data
@@ -1932,7 +1979,7 @@ class PrettyTable:
         # Data
         lines.append("    <tbody>")
         rows = self._get_rows(options)
-        formatted_rows = self._format_rows(rows, options)
+        formatted_rows = self._format_rows(rows)
         for row in formatted_rows:
             lines.append("        <tr>")
             for field, datum in zip(self._field_names, row):
@@ -2007,7 +2054,7 @@ class PrettyTable:
         # Data
         lines.append("    <tbody>")
         rows = self._get_rows(options)
-        formatted_rows = self._format_rows(rows, options)
+        formatted_rows = self._format_rows(rows)
         aligns = []
         valigns = []
         for field in self._field_names:
@@ -2040,6 +2087,124 @@ class PrettyTable:
 
         return "\n".join(lines)
 
+    ##############################
+    # LATEX STRING METHODS       #
+    ##############################
+
+    def get_latex_string(self, **kwargs):
+        """Return string representation of LaTex formatted version of table in current
+        state.
+
+        Arguments:
+
+        start - index of first data row to include in output
+        end - index of last data row to include in output PLUS ONE (list slice style)
+        fields - names of fields (columns) to include
+        header - print a header showing field names (True or False)
+        border - print a border around the table (True or False)
+        hrules - controls printing of horizontal rules after rows.
+            Allowed values: ALL, FRAME, HEADER, NONE
+        vrules - controls printing of vertical rules between columns.
+            Allowed values: FRAME, ALL, NONE
+        int_format - controls formatting of integer data
+        float_format - controls formatting of floating point data
+        sortby - name of field to sort rows by
+        sort_key - sorting key function, applied to data points before sorting
+        format - Controls whether or not HTML tables are formatted to match
+            styling options (True or False)
+        """
+        options = self._get_options(kwargs)
+
+        if options["format"]:
+            string = self._get_formatted_latex_string(options)
+        else:
+            string = self._get_simple_latex_string(options)
+        return string
+
+    def _get_simple_latex_string(self, options):
+        lines = []
+
+        wanted_fields = []
+        if options["fields"]:
+            wanted_fields = [
+                field for field in self._field_names if field in options["fields"]
+            ]
+        else:
+            wanted_fields = self._field_names
+
+        aligments = "".join([self._align[field] for field in wanted_fields])
+
+        begin_cmd = "\\begin{tabular}{%s}" % aligments
+        lines.append(begin_cmd)
+
+        # Headers
+        if options["header"]:
+            lines.append(" & ".join(wanted_fields) + " \\\\")
+
+        # Data
+        rows = self._get_rows(options)
+        formatted_rows = self._format_rows(rows)
+        for row in formatted_rows:
+            wanted_data = [
+                d for f, d in zip(self._field_names, row) if f in wanted_fields
+            ]
+            lines.append(" & ".join(wanted_data) + " \\\\")
+
+        lines.append("\\end{tabular}")
+
+        return "\r\n".join(lines)
+
+    def _get_formatted_latex_string(self, options):
+        lines = []
+
+        wanted_fields = []
+        if options["fields"]:
+            wanted_fields = [
+                field for field in self._field_names if field in options["fields"]
+            ]
+        else:
+            wanted_fields = self._field_names
+
+        wanted_aligments = [self._align[field] for field in wanted_fields]
+        if options["border"] and options["vrules"] == ALL:
+            aligment_str = "|".join(wanted_aligments)
+        else:
+            aligment_str = "".join(wanted_aligments)
+
+        if options["border"] and options["vrules"] in [ALL, FRAME]:
+            aligment_str = "|" + aligment_str + "|"
+
+        begin_cmd = "\\begin{tabular}{%s}" % aligment_str
+        lines.append(begin_cmd)
+
+        if options["border"] and options["hrules"] in [ALL, FRAME]:
+            lines.append("\\hline")
+
+        # Headers
+        if options["header"]:
+            lines.append(" & ".join(wanted_fields) + " \\\\")
+        if options["border"] and options["hrules"] in [ALL, HEADER]:
+            lines.append("\\hline")
+
+        # Data
+        rows = self._get_rows(options)
+        formatted_rows = self._format_rows(rows)
+        rows = self._get_rows(options)
+        for row in formatted_rows:
+            wanted_data = [
+                d for f, d in zip(self._field_names, row) if f in wanted_fields
+            ]
+            lines.append(" & ".join(wanted_data) + " \\\\")
+            if options["border"] and options["hrules"] == ALL:
+                lines.append("\\hline")
+
+        if options["border"] and options["hrules"] == FRAME:
+            lines.append("\\hline")
+
+        lines.append("\\end{tabular}")
+
+        return "\r\n".join(lines)
+
 
 ##############################
 # UNICODE WIDTH FUNCTION     #
